==> odps-center-api-1.1.10-sources.jar: cn/com/duiba/odps/center/api/dto/BankQuickPayDataDto.java <==
package cn.com.duiba.odps.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class BankQuickPayDataDto implements Serializable {

    private static final long serialVersionUID = 7504054369905146362L;
    /**
     * 主键
     **/
    private Long id;
    /**
     * 日期
     **/
    private Date curDate;
    /**
     * appId
     **/
    private Long appId;
    /**
     * 活动Id
     **/
    private Long actId;
    /**
     * 活动名称
     **/
    private String actName;
    /**
     * 活动类型
     **/
    private Integer actType;
    /**
     * 首页访问pv
     **/
    private Long homePagePv;
    /**
     * 首页访问uv
     **/
    private Long homePageUv;
    /**
     * 前往绑卡点击次数
     **/
    private Long goBindCardClickCount;
    /**
     * 前往绑卡点击人数
     **/
    private Long goBindCardClickPerson;
    /**
     * 获取卡号点击次数
     **/
    private Long getCardClickCount;
    /**
     * 获取卡号点击人数
     **/
    private Long getCardClickPerson;
    /**
     * 抢购点击次数
     **/
    private Long panicBuyClickCount;
    /**
     * 抢购点击人数
     **/
    private Long panicBuyClickPerson;
    /**
     * 支付点击次数
     **/
    private Long payClickCount;
    /**
     * 支付点击人数
     **/
    private Long payClickPerson;
    /**
     * 打开微信点击次数
     **/
    private Long openWeixinClickCount;
    /**
     * 打开微信点击人数
     **/
    private Long openWenxinClickPerson;
    /**
     * 开卡点击次数
     **/
    private Long openCardClickCount;
    /**
     * 开卡点击人数
     **/
    private Long openCardClickPerson;
    /**
     * 前往开通点击次数
     **/
    private Long goOpenClickCount;
    /**
     * 前往开通点击人数
     **/
    private Long goOpenClickPerson;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改
     **/
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public String getActName() {
        return actName;
    }

    public void setActName(String actName) {
        this.actName = actName;
    }

    public Integer getActType() {
        return actType;
    }

    public void setActType(Integer actType) {
        this.actType = actType;
    }

    public Long getHomePagePv() {
        return homePagePv;
    }

    public void setHomePagePv(Long homePagePv) {
        this.homePagePv = homePagePv;
    }

    public Long getHomePageUv() {
        return homePageUv;
    }

    public void setHomePageUv(Long homePageUv) {
        this.homePageUv = homePageUv;
    }

    public Long getGoBindCardClickCount() {
        return goBindCardClickCount;
    }

    public void setGoBindCardClickCount(Long goBindCardClickCount) {
        this.goBindCardClickCount = goBindCardClickCount;
    }

    public Long getGoBindCardClickPerson() {
        return goBindCardClickPerson;
    }

    public void setGoBindCardClickPerson(Long goBindCardClickPerson) {
        this.goBindCardClickPerson = goBindCardClickPerson;
    }

    public Long getGetCardClickCount() {
        return getCardClickCount;
    }

    public void setGetCardClickCount(Long getCardClickCount) {
        this.getCardClickCount = getCardClickCount;
    }

    public Long getGetCardClickPerson() {
        return getCardClickPerson;
    }

    public void setGetCardClickPerson(Long getCardClickPerson) {
        this.getCardClickPerson = getCardClickPerson;
    }

    public Long getPanicBuyClickCount() {
        return panicBuyClickCount;
    }

    public void setPanicBuyClickCount(Long panicBuyClickCount) {
        this.panicBuyClickCount = panicBuyClickCount;
    }

    public Long getPanicBuyClickPerson() {
        return panicBuyClickPerson;
    }

    public void setPanicBuyClickPerson(Long panicBuyClickPerson) {
        this.panicBuyClickPerson = panicBuyClickPerson;
    }

    public Long getPayClickCount() {
        return payClickCount;
    }

    public void setPayClickCount(Long payClickCount) {
        this.payClickCount = payClickCount;
    }

    public Long getPayClickPerson() {
        return payClickPerson;
    }

    public void setPayClickPerson(Long payClickPerson) {
        this.payClickPerson = payClickPerson;
    }

    public Long getOpenWeixinClickCount() {
        return openWeixinClickCount;
    }

    public void setOpenWeixinClickCount(Long openWeixinClickCount) {
        this.openWeixinClickCount = openWeixinClickCount;
    }

    public Long getOpenWenxinClickPerson() {
        return openWenxinClickPerson;
    }

    public void setOpenWenxinClickPerson(Long openWenxinClickPerson) {
        this.openWenxinClickPerson = openWenxinClickPerson;
    }

    public Long getOpenCardClickCount() {
        return openCardClickCount;
    }

    public void setOpenCardClickCount(Long openCardClickCount) {
        this.openCardClickCount = openCardClickCount;
    }

    public Long getOpenCardClickPerson() {
        return openCardClickPerson;
    }

    public void setOpenCardClickPerson(Long openCardClickPerson) {
        this.openCardClickPerson = openCardClickPerson;
    }

    public Long getGoOpenClickCount() {
        return goOpenClickCount;
    }

    public void setGoOpenClickCount(Long goOpenClickCount) {
        this.goOpenClickCount = goOpenClickCount;
    }

    public Long getGoOpenClickPerson() {
        return goOpenClickPerson;
    }

    public void setGoOpenClickPerson(Long goOpenClickPerson) {
        this.goOpenClickPerson = goOpenClickPerson;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> odps-center-api-1.1.79-20231017.031658-3-sources.jar: cn/com/duiba/odps/center/api/dto/BankQuickPayDataDto.java <==
package cn.com.duiba.odps.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class BankQuickPayDataDto implements Serializable {

    private static final long serialVersionUID = 7504054369905146362L;
    /**
     * 主键
     **/
    private Long id;
    /**
     * 日期
     **/
    private Date curDate;
    /**
     * appId
     **/
    private Long appId;
    /**
     * 活动Id
     **/
    private Long actId;
    /**
     * 活动名称
     **/
    private String actName;
    /**
     * 活动类型
     **/
    private Integer actType;
    /**
     * 首页访问pv
     **/
    private Long homePagePv;
    /**
     * 首页访问uv
     **/
    private Long homePageUv;
    /**
     * 前往绑卡点击次数
     **/
    private Long goBindCardClickCount;
    /**
     * 前往绑卡点击人数
     **/
    private Long goBindCardClickPerson;
    /**
     * 获取卡号点击次数
     **/
    private Long getCardClickCount;
    /**
     * 获取卡号点击人数
     **/
    private Long getCardClickPerson;
    /**
     * 抢购点击次数
     **/
    private Long panicBuyClickCount;
    /**
     * 抢购点击人数
     **/
    private Long panicBuyClickPerson;
    /**
     * 支付点击次数
     **/
    private Long payClickCount;
    /**
     * 支付点击人数
     **/
    private Long payClickPerson;
    /**
     * 打开微信点击次数
     **/
    private Long openWeixinClickCount;
    /**
     * 打开微信点击人数
     **/
    private Long openWenxinClickPerson;
    /**
     * 开卡点击次数
     **/
    private Long openCardClickCount;
    /**
     * 开卡点击人数
     **/
    private Long openCardClickPerson;
    /**
     * 前往开通点击次数
     **/
    private Long goOpenClickCount;
    /**
     * 前往开通点击人数
     **/
    private Long goOpenClickPerson;
    /**
     * 创建时间
     **/
    private Date gmtCreate;
    /**
     * 修改
     **/
    private Date gmtModified;
    /**
     * 兑换成功次数
     */
    private Long exchangeSuccessCount;
    /**
     * 兑换成功人数
     */
    private Long exchangeSuccessPerson;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getActId() {
        return actId;
    }

    public void setActId(Long actId) {
        this.actId = actId;
    }

    public String getActName() {
        return actName;
    }

    public void setActName(String actName) {
        this.actName = actName;
    }

    public Integer getActType() {
        return actType;
    }

    public void setActType(Integer actType) {
        this.actType = actType;
    }

    public Long getHomePagePv() {
        return homePagePv;
    }

    public void setHomePagePv(Long homePagePv) {
        this.homePagePv = homePagePv;
    }

    public Long getHomePageUv() {
        return homePageUv;
    }

    public void setHomePageUv(Long homePageUv) {
        this.homePageUv = homePageUv;
    }

    public Long getGoBindCardClickCount() {
        return goBindCardClickCount;
    }

    public void setGoBindCardClickCount(Long goBindCardClickCount) {
        this.goBindCardClickCount = goBindCardClickCount;
    }

    public Long getGoBindCardClickPerson() {
        return goBindCardClickPerson;
    }

    public void setGoBindCardClickPerson(Long goBindCardClickPerson) {
        this.goBindCardClickPerson = goBindCardClickPerson;
    }

    public Long getGetCardClickCount() {
        return getCardClickCount;
    }

    public void setGetCardClickCount(Long getCardClickCount) {
        this.getCardClickCount = getCardClickCount;
    }

    public Long getGetCardClickPerson() {
        return getCardClickPerson;
    }

    public void setGetCardClickPerson(Long getCardClickPerson) {
        this.getCardClickPerson = getCardClickPerson;
    }

    public Long getPanicBuyClickCount() {
        return panicBuyClickCount;
    }

    public void setPanicBuyClickCount(Long panicBuyClickCount) {
        this.panicBuyClickCount = panicBuyClickCount;
    }

    public Long getPanicBuyClickPerson() {
        return panicBuyClickPerson;
    }

    public void setPanicBuyClickPerson(Long panicBuyClickPerson) {
        this.panicBuyClickPerson = panicBuyClickPerson;
    }

    public Long getPayClickCount() {
        return payClickCount;
    }

    public void setPayClickCount(Long payClickCount) {
        this.payClickCount = payClickCount;
    }

    public Long getPayClickPerson() {
        return payClickPerson;
    }

    public void setPayClickPerson(Long payClickPerson) {
        this.payClickPerson = payClickPerson;
    }

    public Long getOpenWeixinClickCount() {
        return openWeixinClickCount;
    }

    public void setOpenWeixinClickCount(Long openWeixinClickCount) {
        this.openWeixinClickCount = openWeixinClickCount;
    }

    public Long getOpenWenxinClickPerson() {
        return openWenxinClickPerson;
    }

    public void setOpenWenxinClickPerson(Long openWenxinClickPerson) {
        this.openWenxinClickPerson = openWenxinClickPerson;
    }

    public Long getOpenCardClickCount() {
        return openCardClickCount;
    }

    public void setOpenCardClickCount(Long openCardClickCount) {
        this.openCardClickCount = openCardClickCount;
    }

    public Long getOpenCardClickPerson() {
        return openCardClickPerson;
    }

    public void setOpenCardClickPerson(Long openCardClickPerson) {
        this.openCardClickPerson = openCardClickPerson;
    }

    public Long getGoOpenClickCount() {
        return goOpenClickCount;
    }

    public void setGoOpenClickCount(Long goOpenClickCount) {
        this.goOpenClickCount = goOpenClickCount;
    }

    public Long getGoOpenClickPerson() {
        return goOpenClickPerson;
    }

    public void setGoOpenClickPerson(Long goOpenClickPerson) {
        this.goOpenClickPerson = goOpenClickPerson;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Long getExchangeSuccessCount() {
        return exchangeSuccessCount;
    }

    public void setExchangeSuccessCount(Long exchangeSuccessCount) {
        this.exchangeSuccessCount = exchangeSuccessCount;
    }

    public Long getExchangeSuccessPerson() {
        return exchangeSuccessPerson;
    }

    public void setExchangeSuccessPerson(Long exchangeSuccessPerson) {
        this.exchangeSuccessPerson = exchangeSuccessPerson;
    }
}
